@@ -53,6 +53,9 @@
  */
 
 
+#define MIN(x,y) ((x) < (y) ? (x) : (y))
+
+
 /* -------------------------------------------------------- Public Methods */
 
 
@@ -436,3 +439,28 @@ int Str_compareConstantTime(const void *x, const void *y) {
         return rv;
 }
 
+
+// Escape zero i.e. '\0' in expect buffer with "\0" so zero can be tested in expect strings as "\0". If there are no '\0' in the buffer it is returned as it is
+char *Str_escapeZero(char *buf, int bufferLength, int contentLength) {
+        int currentByteIndex = 0;
+        for (int bytesProcessed = 0; bytesProcessed < contentLength && currentByteIndex < bufferLength; bytesProcessed++, currentByteIndex++) {
+                if (buf[currentByteIndex] == '\0') {
+                        // Escape the zero, unless we run out of space in the buffer. We reserve the last byte for trailing nul-terminator, so if there is no space for the
+                        // nul-terminated escape sequence, we won't perform the escaping and this zero will become the string terminator)
+                        if (currentByteIndex + 1 < bufferLength - 1) {
+                                // Shift the remaining content by one to the right, to make space for '\'. If there's no space for all remaining bytes, we'll truncate the data
+                                memmove(buf + currentByteIndex + 1, buf + currentByteIndex, MIN(contentLength - bytesProcessed, bufferLength - currentByteIndex - 1));
+                                // Escape 0 with "\0"
+                                buf[currentByteIndex] = '\\';
+                                buf[currentByteIndex + 1] = '0';
+                                currentByteIndex++;
+                        }
+                }
+        }
+        if (currentByteIndex < bufferLength)
+                buf[currentByteIndex] = 0;
+        else
+                buf[bufferLength - 1] = 0;
+        return buf;
+}
+
