@@ -4,11 +4,10 @@ PATH="$PATH:."
 export PATH
 
 StrTest && \
-FmtTest && \
+ConvertTest && \
 TimeTest && \
 SystemTest && \
 ListTest && \
-LinkTest && \
 StringBufferTest && \
 DirTest && \
 InputStreamTest && \
