@@ -46,6 +46,10 @@
 #include <strings.h>
 #endif
 
+#ifdef HAVE_GLOB_H
+#include <glob.h>
+#endif
+
 #ifdef HAVE_SYS_STATVFS_H
 # include <sys/statvfs.h>
 #endif
@@ -204,6 +208,80 @@ static bool _getNfsDiskActivity(void *_inf) {
 }
 
 
+static bool _getZfsObjsetId(Info_T inf) {
+        // Find all objset files in the /proc/spl/kstat/zfs/<zpool>/ directory
+        char path[PATH_MAX] = {};
+        snprintf(path, sizeof(path), "/proc/spl/kstat/zfs/%.256s/objset-0x[a-fA-F0-9]*", inf->filesystem->object.key);
+
+        glob_t globbuf;
+        int rv = glob(path, 0, NULL, &globbuf);
+        if (rv) {
+                Log_error("system statistic error -- glob failed: %d (%s)\n", rv, STRERROR);
+                return false;
+        }
+
+        // Scan objset list and find the matching dataset
+        char datasetName[STRLEN] = {};
+        for (size_t i = 0; i < globbuf.gl_pathc; i++) {
+                FILE *f = fopen(globbuf.gl_pathv[i], "r");
+                if (f) {
+                        char line[STRLEN];
+                        while (fgets(line, sizeof(line), f)) {
+                                if (sscanf(line, "dataset_name %*d %255s", datasetName) == 1) {
+                                        if (Str_isByteEqual(datasetName, inf->filesystem->object.device)) {
+                                                // Cache the path to statistics, so we can fetch the data directly next time
+                                                strncpy(inf->filesystem->object.module, globbuf.gl_pathv[i], sizeof(inf->filesystem->object.module) - 1);
+                                                fclose(f);
+                                                return true;
+                                        } else {
+                                                // The dataset name doesn't match, try next objset file
+                                                break;
+                                        }
+                                }
+                        }
+                        fclose(f);
+                }
+        }
+        return false;
+}
+
+
+static bool _updateZfsStatistics(Info_T inf) {
+        FILE *f = fopen(inf->filesystem->object.module, "r");
+        if (f) {
+                char line[STRLEN];
+                long long nread    = -1LL;
+                long long reads    = -1LL;
+                long long nwritten = -1LL;
+                long long writes   = -1LL;
+                while (fgets(line, sizeof(line), f)) {
+                        if (sscanf(line, "nread %*d %lld", &nread) == 1)
+                                continue;
+                        else if (sscanf(line, "reads %*d %lld", &reads) == 1)
+                                continue;
+                        else if (sscanf(line, "nwritten %*d %lld", &nwritten) == 1)
+                                continue;
+                        else if (sscanf(line, "writes %*d %lld", &writes) == 1)
+                                continue;
+                }
+                fclose(f);
+                if (nread >= 0 && reads >= 0 && nwritten >= 0 && writes >= 0) {
+                        unsigned long long now = Time_milli();
+                        Statistics_update(&(inf->filesystem->read.bytes), now, nread);
+                        Statistics_update(&(inf->filesystem->read.operations), now, reads);
+                        Statistics_update(&(inf->filesystem->write.bytes), now, nwritten);
+                        Statistics_update(&(inf->filesystem->write.operations), now, writes);
+                        return true;
+                } else {
+                        Log_error("filesystem statistic error: cannot parse ZFS statistics from %s\n", inf->filesystem->object.module);
+                }
+        } else {
+                Log_error("filesystem statistic error: cannot read ZFS statistics from %s -- %s\n", inf->filesystem->object.module, STRERROR);
+        }
+        return false;
+}
+
+
 static bool _getZfsDiskActivity(void *_inf) {
         Info_T inf = _inf;
         char path[2 * PATH_MAX];
@@ -228,9 +306,16 @@ static bool _getZfsDiskActivity(void *_inf) {
                 }
                 fclose(f);
                 return true;
+        } else {
+                // OpenZFS 2.x
+
+                // We cache the objset ID in the object.module ... if not set, scan the system information
+                if (STR_UNDEF(inf->filesystem->object.module)) {
+                        if (! _getZfsObjsetId(inf))
+                                return false;
+                }
+                return _updateZfsStatistics(inf);
         }
-        Log_error("filesystem statistic error: cannot read %s -- %s\n", path, STRERROR);
-        return false;
 }
 
 
@@ -318,14 +403,20 @@ static bool _compareDevice(const char *device, struct mntent *mnt) {
         int mnt_major, mnt_minor;
         int device_major, device_minor;
         char target[PATH_MAX] = {};
-        return (
+        if (Str_isEqual(device, mnt->mnt_fsname)) {
                 // lookup the device as is first (support for NFS/CIFS/SSHFS/etc.)
-                Str_isEqual(device, mnt->mnt_fsname) ||
+                DEBUG("device %s matches filesystem %s (mounted on %s)\n", device, mnt->mnt_fsname, mnt->mnt_dir);
+                return true;
+        } else if (realpath(mnt->mnt_fsname, target) && Str_isEqual(device, target)) {
                 // The device listed in /etc/mtab can be a device mapper symlink (e.g. /dev/mapper/centos-root -> /dev/dm-1), i.e. try realpath
-                (realpath(mnt->mnt_fsname, target) && Str_isEqual(device, target)) ||
+                DEBUG("device %s matches real path %s for filesystem %s (mounted on %s)\n", device, target, mnt->mnt_fsname, mnt->mnt_dir);
+                return true;
+        } else if (_getDeviceNumbers(device, &device_major, &device_minor) && _getDeviceNumbers(mnt->mnt_fsname, &mnt_major, &mnt_minor) && (mnt_major == device_major) && (mnt_minor == device_minor)) {
                 // The same filesystem may have multiple independent device nodes with the same major+minor number (e.g. block devices /dev/root and /dev/xvda1 for the same filesystem) => if path didn't match, compare major+minor
-                (_getDeviceNumbers(device, &device_major, &device_minor) && _getDeviceNumbers(mnt->mnt_fsname, &mnt_major, &mnt_minor) && (mnt_major == device_major) && (mnt_minor == device_minor))
-        );
+                DEBUG("device %s with major=%d and minor=%d number matches filesystem %s (mounted on %s)\n", device, mnt_major, mnt_minor, mnt->mnt_fsname, mnt->mnt_dir);
+                return true;
+        }
+        return false;
 }
 
 
@@ -338,7 +429,7 @@ static bool _setDevice(Info_T inf, const char *path, bool (*compare)(const char
         inf->filesystem->object.generation = _statistics.generation;
         bool mounted = false;
         struct mntent *mnt;
-        char flags[STRLEN];
+        char flags[STRLEN] = {};
         while ((mnt = getmntent(f))) {
                 // Scan all entries for overlay mounts (common for rootfs)
                 if (compare(path, mnt)) {
@@ -385,13 +476,9 @@ static bool _setDevice(Info_T inf, const char *path, bool (*compare)(const char
         if (! mounted) {
                 Log_error("Lookup for '%s' filesystem failed  -- not found in %s\n", path, MOUNTS);
         } else {
-                // Evaluate filesystem flags for the last matching mount (overlay mounts for the same filesystem may have different mount flags)
-                if (! IS(flags, inf->filesystem->flags)) {
-                        if (*(inf->filesystem->flags)) {
-                                inf->filesystem->flagsChanged = true;
-                        }
-                        snprintf(inf->filesystem->flags, sizeof(inf->filesystem->flags), "%s", flags);
-                }
+                // Store the flags value at the end. The same filesystem may have overlay mounts (with different flags), we don't want to corrupt the flags in the monit status, until we find the (last) matching filesystem
+                Util_swapFilesystemFlags(&(inf->filesystem->flags));
+                snprintf(inf->filesystem->flags.current, sizeof(inf->filesystem->flags.value[0]), "%s", flags);
         }
         return mounted;
 }
@@ -418,6 +505,8 @@ static bool _getDevice(Info_T inf, const char *path, bool (*compare)(const char
         if (inf->filesystem->object.generation != _statistics.generation || _statistics.fd == -1) {
                 DEBUG("Reloading mount information for filesystem '%s'\n", path);
                 _setDevice(inf, path, compare);
+        } else {
+                strncpy(inf->filesystem->flags.previous, inf->filesystem->flags.current, sizeof(inf->filesystem->flags.value[0]));
         }
         if (inf->filesystem->object.mounted) {
                 return (inf->filesystem->object.getDiskUsage(inf) && inf->filesystem->object.getDiskActivity(inf));
