@@ -55,8 +55,9 @@
 #include "monit.h"
 #include "ProcessTree.h"
 #include "device.h"
-#include "Color.h"
-#include "Box.h"
+#include "TextColor.h"
+#include "TextBox.h"
+#include "httpstatus.h"
 #include "client.h"
 
 // libmonit
@@ -74,7 +75,7 @@
 
 
 static void _argument(StringBuffer_T data, const char *name, const char *value) {
-        char *_value = Util_urlEncode((char *)value, true);
+        char *_value = Util_urlEncode(value, true);
         StringBuffer_append(data, "%s%s=%s", StringBuffer_length(data) ? "&" : "", name, _value);
         FREE(_value);
 }
@@ -104,7 +105,13 @@ static void _parseHttpResponse(Socket_T S) {
         int status;
         if (! sscanf(buf, "%*s %d", &status))
                 THROW(IOException, "Cannot parse status in response: %s", buf);
-        if (status >= 300) {
+        if (status < 300 || status == SC_MOVED_TEMPORARILY) {
+                // Skip HTTP headers
+                while (Socket_readLine(S, buf, sizeof(buf))) {
+                         if (! strncmp(buf, "\r\n", sizeof(buf)))
+                                break;
+                }
+        } else {
                 int content_length = 0;
                 // Read HTTP headers
                 while (Socket_readLine(S, buf, sizeof(buf))) {
@@ -126,12 +133,6 @@ static void _parseHttpResponse(Socket_T S) {
                         }
                 }
                 THROW(AssertException, "%s", message ? message : "cannot parse response");
-        } else {
-                // Skip HTTP headers
-                while (Socket_readLine(S, buf, sizeof(buf))) {
-                         if (! strncmp(buf, "\r\n", sizeof(buf)))
-                                break;
-                }
         }
 }
 
@@ -163,10 +164,10 @@ static void _send(Socket_T S, const char *request, StringBuffer_T data) {
 static void _receive(Socket_T S) {
         char buf[1024];
         _parseHttpResponse(S);
-        bool strip = (Run.flags & Run_Batch || ! Color_support()) ? true : false;
+        bool strip = (Run.flags & Run_Batch || ! TextColor_support()) ? true : false;
         while (Socket_readLine(S, buf, sizeof(buf))) {
                 if (strip)
-                        Color_strip(Box_strip(buf));
+                        TextColor_strip(TextBox_strip(buf));
                 printf("%s", buf);
         }
 }
@@ -179,7 +180,8 @@ static bool _client(const char *request, StringBuffer_T data) {
                 return status;
         }
         Socket_T S = NULL;
-        if (Run.httpd.flags & Httpd_Net) {
+        // Connect via http if enabled except if set readonly and a unix socket was configured not readonly
+        if ((Run.httpd.flags & Httpd_Net) && !(Run.httpd.socket.net.readonly && (Run.httpd.flags & Httpd_Unix) && !Run.httpd.socket.unix.readonly)) {
                 S = Socket_create(Run.httpd.socket.net.address ? Run.httpd.socket.net.address : "localhost", Run.httpd.socket.net.port, Socket_Tcp, Socket_Ip, &(Run.httpd.socket.net.ssl), Run.limits.networkTimeout);
         } else if (Run.httpd.flags & Httpd_Unix) {
                 S = Socket_createUnix(Run.httpd.socket.unix.path, Socket_Tcp, Run.limits.networkTimeout);
@@ -224,8 +226,10 @@ bool HttpClient_action(const char *action, List_T services) {
 }
 
 
-bool HttpClient_report(const char *type) {
+bool HttpClient_report(const char *group, const char *type) {
         StringBuffer_T data = StringBuffer_create(64);
+        if (STR_DEF(group))
+                _argument(data, "group", group);
         if (STR_DEF(type))
                 _argument(data, "type", type);
         bool rv = _client("/_report", data);
