@@ -517,6 +517,8 @@ static void send_response(HttpRequest req, HttpResponse res) {
                 Socket_print(S, "Server: %s\r\n", server);
                 Socket_print(S, "Content-Length: %zu\r\n", bodyLength);
                 Socket_print(S, "Connection: close\r\n");
+                Socket_print(S, "X-Frame-Options: SAMEORIGIN\r\n");
+                Socket_print(S, "Content-Security-Policy: frame-ancestors 'self'\r\n");
                 if (headers)
                         Socket_print(S, "%s", headers);
                 Socket_print(S, "\r\n");
@@ -870,6 +872,8 @@ static void internal_error(Socket_T S, int status, const char *msg) {
                      "Server: %s\r\n"
                      "Content-Type: text/html\r\n"
                      "Connection: close\r\n"
+                     "X-Frame-Options: SAMEORIGIN\r\n"
+                     "Content-Security-Policy: frame-ancestors 'self'\r\n"
                      "\r\n"
                      "<html><head><title>%s</title></head>"
                      "<body bgcolor=#FFFFFF><h2>%s</h2>%s<p>"
