@@ -109,7 +109,7 @@
 
 
 static void  do_init(void);                   /* Initialize this application */
-static void  do_reinit(void);       /* Re-initialize the runtime application */
+static void  do_reinit(bool full);  /* Re-initialize the runtime application */
 static void  do_action(List_T);          /* Dispatch to the submitted action */
 static void  do_exit(bool);                           /* Finalize monit */
 static void  do_default(void);                          /* Do default action */
@@ -170,7 +170,16 @@ int main(int argc, char **argv) {
 #endif
         init_env();
         List_T arguments = List_new();
-        handle_options(argc, argv, arguments);
+        TRY
+        {
+                handle_options(argc, argv, arguments);
+        }
+        ELSE
+        {
+                Log_error("%s\n", Exception_frame.message);
+                exit(1);
+        }
+        END_TRY;
         do_init();
         do_action(arguments);
         List_free(&arguments);
@@ -330,7 +339,7 @@ static void do_init() {
  * Re-Initialize the application - called if a
  * monit daemon receives the SIGHUP signal.
  */
-static void do_reinit() {
+static void do_reinit(bool full) {
         Log_info("Reinitializing Monit -- control file '%s'\n", Run.files.control);
 
         /* Wait non-blocking for any children that has exited. Since we
@@ -354,7 +363,8 @@ static void do_reinit() {
                 monit_http(Httpd_Stop);
 
         /* Save the current state (no changes are possible now since the http thread is stopped) */
-        State_save();
+        if (full)
+                State_save();
         State_close();
 
         /* Run the garbage collector */
@@ -391,20 +401,42 @@ static void do_reinit() {
                 exit(1);
         State_restore();
 
-        /* Start http interface */
-        if (can_http())
-                monit_http(Httpd_Start);
+        if (full) {
+                /* Start http interface */
+                if (can_http())
+                        monit_http(Httpd_Start);
 
-        /* send the monit startup notification */
-        Event_post(Run.system, Event_Instance, State_Changed, Run.system->action_MONIT_START, "Monit reloaded");
+                /* send the monit startup notification */
+                Event_post(Run.system, Event_Instance, State_Changed, Run.system->action_MONIT_START, "Monit reloaded");
 
-        if (Run.mmonits) {
-                Thread_create(heartbeatThread, heartbeat, NULL);
-                heartbeatRunning = true;
+                if (Run.mmonits) {
+                        Thread_create(heartbeatThread, heartbeat, NULL);
+                        heartbeatRunning = true;
+                }
         }
 }
 
 
+static bool _isMemberOfGroup(Service_T s, ServiceGroup_T g) {
+        for (list_t m = g->members->head; m; m = m->next) {
+                Service_T member = m->e;
+                if (s == member)
+                        return true;
+        }
+        return false;
+}
+
+
+static bool _hasParentInTheSameGroup(Service_T s, ServiceGroup_T g) {
+        for (Dependant_T d = s->dependantlist; d; d = d->next ) {
+                Service_T parent = Util_getService(d->dependant);
+                if (parent && _isMemberOfGroup(parent, g))
+                        return true;
+        }
+        return false;
+}
+
+
 /**
  * Dispatch to the submitted action - actions are program arguments
  */
@@ -429,6 +461,10 @@ static void do_action(List_T arguments) {
                                         if (IS(Run.mygroup, sg->name)) {
                                                 for (list_t m = sg->members->head; m; m = m->next) {
                                                         Service_T s = m->e;
+                                                        if (IS(action, "restart") && _hasParentInTheSameGroup(s, sg)) {
+                                                                DEBUG("Restart of %s skipped -- it'll be handled as part of the dependency chain, as the parent service is member of the same group\n", s->name);
+                                                                continue;
+                                                        }
                                                         List_append(services, s->name);
                                                 }
                                                 break;
@@ -466,7 +502,7 @@ static void do_action(List_T arguments) {
                         exit(1);
         } else if (IS(action, "report")) {
                 char *type = List_pop(arguments);
-                if (! HttpClient_report(type))
+                if (! HttpClient_report(Run.mygroup, type))
                         exit(1);
         } else if (IS(action, "procmatch")) {
                 char *pattern = List_pop(arguments);
@@ -558,9 +594,10 @@ static void do_default() {
 
                 atexit(file_finalize);
 
+reload:
                 if (Run.startdelay) {
                         if (State_reboot()) {
-                                time_t now = Time_now();
+                                time_t now = Time_monotonic();
                                 time_t delay = now + Run.startdelay;
 
                                 Log_info("Monit will delay for %ds on first start after reboot ...\n", Run.startdelay);
@@ -568,9 +605,13 @@ static void do_default() {
                                 /* sleep can be interrupted by signal => make sure we paused long enough */
                                 while (now < delay) {
                                         sleep((unsigned int)(delay - now));
-                                        if (Run.flags & Run_Stopped)
+                                        if (Run.flags & Run_Stopped) {
                                                 do_exit(false);
-                                        now = Time_now();
+                                        } else if (Run.flags & Run_DoReload) {
+                                                do_reinit(false);
+                                                goto reload;
+                                        }
+                                        now = Time_monotonic();
                                 }
                         } else {
                                 DEBUG("Monit delay %ds skipped -- the system boot time has not changed since last Monit start\n", Run.startdelay);
@@ -603,7 +644,7 @@ static void do_default() {
                         if (Run.flags & Run_Stopped) {
                                 do_exit(true);
                         } else if (Run.flags & Run_DoReload) {
-                                do_reinit();
+                                do_reinit(true);
                         } else {
                                 State_saveIfDirty();
                         }
@@ -654,11 +695,14 @@ static void handle_options(int argc, char **argv, List_T arguments) {
                                 {
                                         char *f = optarg;
                                         char realpath[PATH_MAX] = {};
+                                        if (Run.files.control) {
+                                                Log_warning("WARNING: The -c option was specified multiple times, only the last value will be used\n");
+                                                FREE(Run.files.control);
+                                        }
                                         if (f[0] != SEPARATOR_CHAR)
                                                 f = File_getRealPath(optarg, realpath);
                                         if (! f)
-                                                THROW(AssertException, "The control file '%s' does not exist at %s",
-                                                      Str_trunc(optarg, 80), Dir_cwd((char[STRLEN]){}, STRLEN));
+                                                THROW(AssertException, "The control file '%s' does not exist at %s", Str_trunc(optarg, 80), Dir_cwd((char[STRLEN]){}, STRLEN));
                                         if (! File_isFile(f))
                                                 THROW(AssertException, "The control file '%s' is not a file", Str_trunc(f, 80));
                                         if (! File_isReadable(f))
@@ -677,11 +721,19 @@ static void handle_options(int argc, char **argv, List_T arguments) {
                                 }
                                 case 'g':
                                 {
+                                        if (Run.mygroup) {
+                                                Log_warning("WARNING: The -g option was specified multiple times, only the last value will be used\n");
+                                                FREE(Run.mygroup);
+                                        }
                                         Run.mygroup = Str_dup(optarg);
                                         break;
                                 }
                                 case 'l':
                                 {
+                                        if (Run.files.log) {
+                                                Log_warning("WARNING: The -l option was specified multiple times, only the last value will be used\n");
+                                                FREE(Run.files.log);
+                                        }
                                         Run.files.log = Str_dup(optarg);
                                         if (IS(Run.files.log, "syslog"))
                                                 Run.flags |= Run_UseSyslog;
@@ -690,11 +742,19 @@ static void handle_options(int argc, char **argv, List_T arguments) {
                                 }
                                 case 'p':
                                 {
+                                        if (Run.files.pid) {
+                                                Log_warning("WARNING: The -p option was specified multiple times, only the last value will be used\n");
+                                                FREE(Run.files.pid);
+                                        }
                                         Run.files.pid = Str_dup(optarg);
                                         break;
                                 }
                                 case 's':
                                 {
+                                        if (Run.files.state) {
+                                                Log_warning("WARNING: The -s option was specified multiple times, only the last value will be used\n");
+                                                FREE(Run.files.state);
+                                        }
                                         Run.files.state = Str_dup(optarg);
                                         break;
                                 }
@@ -883,7 +943,7 @@ static void version() {
         printf("out");
 #endif
         printf(" large files\n");
-        printf("Copyright (C) 2001-2020 Tildeslash Ltd. All Rights Reserved.\n");
+        printf("Copyright (C) 2001-2022 Tildeslash Ltd. All Rights Reserved.\n");
 }
 
 
