@@ -172,7 +172,8 @@ typedef enum {
 
 
 typedef enum {
-        Every_Cycle = 0,
+        Every_Initializing = 0,
+        Every_Cycle,
         Every_SkipCycles,
         Every_Cron,
         Every_NotInCron
@@ -639,6 +640,13 @@ typedef struct Outgoing_T {
 } Outgoing_T;
 
 
+typedef struct ResponseTime_T {
+        Operator_Type operator;
+        double current;                            /**< Current response time [ms] */
+        double limit;                                /**< Response time limit [ms] */
+} ResponseTime_T;
+
+
 /** Defines a port object */
 typedef struct Port_T {
         char *hostname;                                     /**< Hostname to check */
@@ -658,10 +666,11 @@ typedef struct Port_T {
                 } net;
         } target;
         Outgoing_T outgoing;                                 /**< Outgoing address */
+        bool check_invers;           /**< Whether to alert on a connection success */
         int timeout;      /**< The timeout in [ms] to wait for connect or read i/o */
         int retry;       /**< Number of connection retry before reporting an error */
         volatile int socket;                       /**< Socket used for connection */
-        double response;                 /**< Socket connection response time [ms] */
+        struct ResponseTime_T responsetime;               /**< Response time limit */
         Socket_Type type;           /**< Socket type used for connection (UDP/TCP) */
         Socket_Family family;    /**< Socket family used for connection (NET/UNIX) */
         Connection_State is_available;               /**< Server/port availability */
@@ -718,6 +727,11 @@ typedef struct Port_T {
                         char *rsaChecksum;
                         Hash_Type rsaChecksumType;
                 } mysql;
+                struct {
+                        char *username;
+                        char *password;
+                        char *database;
+                } postgresql;
                 struct {
                         char *secret;
                 } radius;
@@ -750,9 +764,10 @@ typedef struct Icmp_T {
         int size;                                     /**< ICMP echo requests size */
         int count;                                   /**< ICMP echo requests count */
         int timeout;         /**< The timeout in milliseconds to wait for response */
+        bool check_invers;           /**< Whether to alert on a connection success */
         Connection_State is_available;    /**< Flag for the server is availability */
         Socket_Family family;                 /**< ICMP family used for connection */
-        double response;                         /**< ICMP ECHO response time [ms] */
+        struct ResponseTime_T responsetime;               /**< Response time limit */
         Outgoing_T outgoing;                                 /**< Outgoing address */
         EventAction_T action; /**< Description of the action upon event occurrence */
 
@@ -812,7 +827,7 @@ typedef struct ActionRate_T {
 /** Defines when to run a check for a service. This type supports both the old
  cycle based every statement and the new cron-format version */
 typedef struct Every_T {
-        Every_Type type; /**< 0 = not set, 1 = cycle, 2 = cron, 3 = negated cron */
+        Every_Type type;
         time_t last_run;
         union {
                 struct {
@@ -872,6 +887,7 @@ typedef struct Uptime_T {
 
 
 typedef struct LinkStatus_T {
+        bool check_invers;                      /**< Whether to alert on a link up */
         EventAction_T action; /**< Description of the action upon event occurrence */
 
         /** For internal use */
@@ -913,11 +929,11 @@ typedef struct Bandwidth_T {
 
 /** Defines checksum object */
 typedef struct Checksum_T {
-        bool initialized;               /**< true if checksum was initialized */
-        bool test_changes;       /**< true if we only should test for changes */
+        bool initialized;                    /**< true if checksum was initialized */
+        bool test_changes;            /**< true if we only should test for changes */
         Hash_Type type;                   /**< The type of hash (e.g. md5 or sha1) */
         int   length;                                      /**< Length of the hash */
-        MD_T  hash;                     /**< A checksum hash computed for the path */
+        char  hash[MD_SIZE + 1];        /**< A checksum hash computed for the path */
         EventAction_T action; /**< Description of the action upon event occurrence */
 } *Checksum_T;
 
@@ -1040,10 +1056,10 @@ typedef struct Device_T {
                 int minor;
         } number;
         char partition;
-        char device[PATH_MAX];
-        char mountpoint[PATH_MAX];
-        char key[PATH_MAX];
-        char module[256];
+        char device[PATH_MAX + 1];
+        char mountpoint[PATH_MAX + 1];
+        char key[PATH_MAX + 1];
+        char module[PATH_MAX + 1];
         char type[64];
         unsigned long long flags;
         bool (*getDiskUsage)(void *);
@@ -1058,6 +1074,13 @@ typedef struct TimestampInfo_T {
 } *TimestampInfo_T;
 
 
+typedef struct FilesystemFlags_T {
+        char value[2][STRLEN];
+        char *current;
+        char *previous;
+} *FilesystemFlags_T;
+
+
 typedef struct FileSystemInfo_T {
         long long  f_blocks;              /**< Total data blocks in filesystem */
         long long  f_blocksfree;   /**< Free blocks available to non-superuser */
@@ -1072,8 +1095,7 @@ typedef struct FileSystemInfo_T {
         int uid;                                              /**< Owner's uid */
         int gid;                                              /**< Owner's gid */
         int mode;                                              /**< Permission */
-        char flags[STRLEN];                              /**< Filesystem flags */
-        bool flagsChanged;          /**< True if filesystem flags changed */
+        struct FilesystemFlags_T flags;                  /**< Filesystem flags */
         struct IOStatistics_T read;                       /**< Read statistics */
         struct IOStatistics_T write;                     /**< Write statistics */
         struct {
@@ -1175,6 +1197,7 @@ typedef struct Service_T {
         State_Type (*check)(struct Service_T *);/**< Service verification function */
         bool onrebootRestored;
         bool visited; /**< Service visited flag, set if dependencies are used */
+        bool inverseStatus;
         Service_Type type;                             /**< Monitored service type */
         Monitor_State monitor;                             /**< Monitor state flag */
         Monitor_Mode mode;                    /**< Monitoring mode for the service */
@@ -1239,7 +1262,6 @@ typedef struct Service_T {
         int                error_hint;   /**< Failed/Changed hint for error bitmap */
         union Info_T       inf;                          /**< Service check result */
         struct timeval     collected;                /**< When were data collected */ //FIXME: replace with unsigned long long? (all places where timeval is used) ... Time_milli()?
-        char              *token;                                /**< Action token */
 
         /** Events */
         struct myevent {
@@ -1318,12 +1340,14 @@ struct Run_T {
                                 int  port;
                                 char *address;
                                 struct SslOptions_T ssl;
+                                bool readonly;
                         } net;
                         struct {
                                 int uid;
                                 int gid;
                                 int permission;
                                 char *path;
+                                bool readonly;
                         } unix;
                 } socket;
                 Auth_T credentials;
