@@ -160,10 +160,10 @@ static int _fill(T S, int timeout) {
 
 static int _getPort(const struct sockaddr *addr) {
         if (addr->sa_family == AF_INET)
-                return ntohs(((struct sockaddr_in *)addr)->sin_port);
+                return ntohs(((const struct sockaddr_in *)addr)->sin_port);
 #ifdef HAVE_IPV6
         else if (addr->sa_family == AF_INET6)
-                return ntohs(((struct sockaddr_in6 *)addr)->sin6_port);
+                return ntohs(((const struct sockaddr_in6 *)addr)->sin6_port);
 #endif
         else
                 return -1;
@@ -173,7 +173,7 @@ static int _getPort(const struct sockaddr *addr) {
 static char *_addressToString(const struct sockaddr *addr, socklen_t addrlen, char *buf, int buflen) {
         int oerrno = errno;
         if (addr->sa_family == AF_UNIX) {
-                snprintf(buf, buflen, "%s", ((struct sockaddr_un *)addr)->sun_path);
+                snprintf(buf, buflen, "%s", ((const struct sockaddr_un *)addr)->sun_path);
         } else {
                 char ip[NI_MAXHOST];
                 char port[NI_MAXSERV];
@@ -502,6 +502,11 @@ Socket_Type Socket_getType(T S) {
         return S->type;
 }
 
+Socket_Family Socket_getFamily(T S) {
+        ASSERT(S);
+        return S->family;
+}
+
 
 void *Socket_getPort(T S) {
         ASSERT(S);
@@ -648,13 +653,13 @@ void Socket_test(void *P) {
                                 THROW(IOException, "Invalid socket family %d\n", p->family);
                                 break;
                 }
-                p->response = (double)(Time_micro() - start) / 1000.; // Convert microseconds to milliseconds
+                p->responsetime.current = (double)(Time_micro() - start) / 1000.; // Convert microseconds to milliseconds
                 p->is_available = Connection_Ok;
         }
         ELSE
         {
                 p->is_available = Connection_Failed;
-                p->response = -1.;
+                p->responsetime.current = -1.;
                 RETHROW;
         }
         END_TRY;
@@ -701,7 +706,7 @@ int Socket_write(T S, const void *b, size_t size) {
 #endif
                 if (n <= 0)
                         break;
-                p = (unsigned char *)p + n;
+                p = (const unsigned char *)p + n;
                 size -= n;
 
         }
@@ -709,7 +714,7 @@ int Socket_write(T S, const void *b, size_t size) {
                 /* No write or a partial write is an error */
                 return -1;
         }
-        return  (int)((unsigned char *)p - (unsigned char *)b);
+        return  (int)((const unsigned char *)p - (const unsigned char *)b);
 }
 
 
