@@ -586,39 +586,40 @@ int getloadavg_sysdep(double *loadv, int nelem) {
 bool used_system_memory_sysdep(SystemInfo_T *si) {
         char          *ptr;
         char           buf[2048];
-        unsigned long  mem_available = 0UL;
-        unsigned long  mem_free = 0UL;
-        unsigned long  buffers = 0UL;
-        unsigned long  cached = 0UL;
-        unsigned long  slabreclaimable = 0UL;
-        unsigned long  swap_total = 0UL;
-        unsigned long  swap_free = 0UL;
-        unsigned long long       zfsarcsize = 0ULL;
+        unsigned long long mem_total = 0ULL;
+        unsigned long long mem_available = 0ULL;
+        unsigned long long mem_free = 0ULL;
+        unsigned long long buffers = 0ULL;
+        unsigned long long cached = 0ULL;
+        unsigned long long slabreclaimable = 0ULL;
+        unsigned long long swap_total = 0ULL;
+        unsigned long long swap_free = 0ULL;
+        unsigned long long zfsarcsize = 0ULL;
 
         if (! file_readProc(buf, sizeof(buf), "meminfo", -1, NULL)) {
                 Log_error("system statistic error -- cannot get system memory info\n");
                 goto error;
         }
 
-        /*
-         * Memory
-         *
-         * First, check if the "MemAvailable" value is available on this system. If it is, we will
-         * use it. Otherwise we will attempt to calculate the amount of available memory ourself.
-         */
-        if ((ptr = strstr(buf, "MemAvailable:")) && sscanf(ptr + 13, "%lu", &mem_available) == 1) {
-                si->memory.usage.bytes = systeminfo.memory.size - (unsigned long long)mem_available * 1024;
+        // Update memory total (physical memory can be added to the online system on some machines, also LXC/KVM containers MemTotal is dynamic and changes frequently
+        if ((ptr = strstr(buf, "MemTotal:")) && sscanf(ptr + 9, "%llu", &mem_total) == 1) {
+                systeminfo.memory.size = mem_total * 1024;
+        }
+
+        // Check if the "MemAvailable" value is available on this system. If it is, we will use it. Otherwise we will attempt to calculate the amount of available memory ourself
+        if ((ptr = strstr(buf, "MemAvailable:")) && sscanf(ptr + 13, "%llu", &mem_available) == 1) {
+                si->memory.usage.bytes = systeminfo.memory.size - mem_available * 1024;
         } else {
                 DEBUG("'MemAvailable' value not available on this system. Attempting to calculate available memory manually...\n");
-                if (! (ptr = strstr(buf, "MemFree:")) || sscanf(ptr + 8, "%lu", &mem_free) != 1) {
+                if (! (ptr = strstr(buf, "MemFree:")) || sscanf(ptr + 8, "%llu", &mem_free) != 1) {
                         Log_error("system statistic error -- cannot get real memory free amount\n");
                         goto error;
                 }
-                if (! (ptr = strstr(buf, "Buffers:")) || sscanf(ptr + 8, "%lu", &buffers) != 1)
+                if (! (ptr = strstr(buf, "Buffers:")) || sscanf(ptr + 8, "%llu", &buffers) != 1)
                         DEBUG("system statistic error -- cannot get real memory buffers amount\n");
-                if (! (ptr = strstr(buf, "Cached:")) || sscanf(ptr + 7, "%lu", &cached) != 1)
+                if (! (ptr = strstr(buf, "Cached:")) || sscanf(ptr + 7, "%llu", &cached) != 1)
                         DEBUG("system statistic error -- cannot get real memory cache amount\n");
-                if (! (ptr = strstr(buf, "SReclaimable:")) || sscanf(ptr + 13, "%lu", &slabreclaimable) != 1)
+                if (! (ptr = strstr(buf, "SReclaimable:")) || sscanf(ptr + 13, "%llu", &slabreclaimable) != 1)
                         DEBUG("system statistic error -- cannot get slab reclaimable memory amount\n");
                 FILE *f = fopen("/proc/spl/kstat/zfs/arcstats", "r");
                 if (f) {
@@ -633,17 +634,17 @@ bool used_system_memory_sysdep(SystemInfo_T *si) {
                 si->memory.usage.bytes = systeminfo.memory.size - zfsarcsize - (unsigned long long)(mem_free + buffers + cached + slabreclaimable) * 1024;
         }
 
-        /* Swap */
-        if (! (ptr = strstr(buf, "SwapTotal:")) || sscanf(ptr + 10, "%lu", &swap_total) != 1) {
+        // Swap
+        if (! (ptr = strstr(buf, "SwapTotal:")) || sscanf(ptr + 10, "%llu", &swap_total) != 1) {
                 Log_error("system statistic error -- cannot get swap total amount\n");
                 goto error;
         }
-        if (! (ptr = strstr(buf, "SwapFree:")) || sscanf(ptr + 9, "%lu", &swap_free) != 1) {
+        if (! (ptr = strstr(buf, "SwapFree:")) || sscanf(ptr + 9, "%llu", &swap_free) != 1) {
                 Log_error("system statistic error -- cannot get swap free amount\n");
                 goto error;
         }
-        si->swap.size = (unsigned long long)swap_total * 1024;
-        si->swap.usage.bytes = (unsigned long long)(swap_total - swap_free) * 1024;
+        si->swap.size = swap_total * 1024;
+        si->swap.usage.bytes = (swap_total - swap_free) * 1024;
 
         return true;
 
