@@ -73,7 +73,7 @@ int getloadavg_sysdep (double *loadv, int nelem) {
  * This routine returns kbyte of real memory in use.
  * @return: true if successful, false if failed (or not available)
  */
-boolean_t used_system_memory_sysdep(SystemInfo_T *si) {
+bool used_system_memory_sysdep(SystemInfo_T *si) {
         return false;
 }
 
@@ -82,7 +82,17 @@ boolean_t used_system_memory_sysdep(SystemInfo_T *si) {
  * This routine returns system/user CPU time in use.
  * @return: true if successful, false if failed (or not available)
  */
-boolean_t used_system_cpu_sysdep(SystemInfo_T *si) {
+bool used_system_cpu_sysdep(SystemInfo_T *si) {
+        return false;
+}
+
+
+bool used_system_filedescriptors_sysdep(SystemInfo_T *si) {
+        return false;
+}
+
+
+bool available_statistics(SystemInfo_T *si) {
         return false;
 }
 
